﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Path = System.Windows.Shapes.Path;

namespace Compdfkit_Tools.PDFControl
{
    /// <summary>
    /// Interaction logic for HomePageControl.xaml
    /// </summary>
    public partial class HomePageControl : UserControl
    {

        Canvas viewerCanvas = new Canvas();
        Canvas annotationsCanvas = new Canvas();
        Canvas formsCanvas = new Canvas();
        Canvas signatureCanvas = new Canvas();
        Canvas documentEditorCanvas = new Canvas();
        Canvas contentEditorCanvas = new Canvas();
        Canvas securityCanvas = new Canvas();
        Canvas redactionCanvas = new Canvas();
        Canvas waterCanvas = new Canvas();

        private List<CustomItem> customItems;

        public HomePageControl()
        {
            InitializeComponent();
        }

        private void ImportFeatures()
        {
            if (FeaturesListControl != null)
            {
                foreach (CustomItem item in customItems)
                {
                    FeaturesListControl.Items.Add(item);
                }
            }
            FeaturesListControl.SelectionChanged -= FeaturesListControl_SelectionChanged;
            FeaturesListControl.SelectionChanged += FeaturesListControl_SelectionChanged;
        }

        private void FeaturesListControl_SelectionChanged(object sender, CustomItem e)
        {
            var parentWindow = Window.GetWindow(this);

            switch (e.TitleText)
            {
                case "Watermark":
                    {
                        WatermarkOperationTypeDialog watermarkOperationTypeDialog = new WatermarkOperationTypeDialog()
                        {
                            Owner = parentWindow
                        };
                        watermarkOperationTypeDialog.ShowDialog();
                        break;
                    }
                case "Security":
                    {
                        SecurityOperationTypeDialog securityOperationTypeDialog = new SecurityOperationTypeDialog()
                        {
                            Owner = parentWindow
                        };
                        securityOperationTypeDialog.ShowDialog();
                        break;
                    }
                default:
                    MessageBox.Show(e.TitleText + " is under development.");
                    break;
            }
        }



        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {
            CreatFeatureIcon();

            CreateCustomItems();

            ImportFeatures();
        }

        private void CreateCustomItems()
        {
            customItems = new List<CustomItem>()
            {
                new CustomItem{ IconCanvas = viewerCanvas,TitleText = "Viewer", DescriptionText="View PDFs with tools like display modes, navigation, reading themes, scrolling, zooming, text searching, text reflow, split viewer, etc."},
                new CustomItem{ IconCanvas = annotationsCanvas,TitleText= "Annotations", DescriptionText="Annotate and markup PDFs with notes, links, texts, line, square, arrow, circle, highlight, underline, squiggly, strikeout, stamps, ink, signature, sound, etc. Allow to create, delete, edit, import, export, and flatten PDF annotations." },
                new CustomItem{ IconCanvas = formsCanvas, TitleText="Forms", DescriptionText="Create, delete, edit, fill, flatten, import, and export forms. Support a wide array of PDF form fields including text field, check box, radio button, list box, combo button, push button, and signatures."},
                new CustomItem{ IconCanvas = signatureCanvas,TitleText="Signature", DescriptionText="Sign PDFs with digital signatures and electronic signatures. Choose the drawn, image, or typed signatures and sign files conveniently. Or sign with your digital ID securely.\r\n"},
                new CustomItem{ IconCanvas = documentEditorCanvas, TitleText="Document Editor", DescriptionText="Process PDF pages and files. Add, insert, replace, extract, reverse, move, copy, paste, rotate, delete, crop, scale, etc."},
                new CustomItem{ IconCanvas = contentEditorCanvas, TitleText="Content Editor", DescriptionText="Edit the text and images with ComPDFKit Content Editor. Give you the freedom to adjust the size, position, style, font, etc.\r\n"},
                new CustomItem{ IconCanvas = securityCanvas,TitleText="Security", DescriptionText="Secure your documents using AES-128, AES-256, or RC4 encryption and decrypt PDFs. Customize permissions, edit headers & footers, change the background, insert or remove Bates numbers for indexing, etc.\r\n"},
                new CustomItem{ IconCanvas = redactionCanvas,TitleText="Redaction", DescriptionText="Use redaction to remove sensitive images, text, and vector graphics, that can't be recovered after applying the redaction. Support customizing redaction appearance and choosing an area or searching for specific text to redact.\r\n"},
                new CustomItem{ IconCanvas = waterCanvas,TitleText="Watermark", DescriptionText="Create, insert, and remove text or image watermarks to brand your users' work and discourage its unauthorized use.\r\n"},
            };
        }

        private void CreatFeatureIcon()
        {
            //Viewer
            {
                Path path1 = new Path
                {
                    Data = Geometry.Parse("M13.2071 1.5H2.5V18.5H17.5V5.79289L13.2071 1.5Z"),
                    Fill = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#80477EDE")),
                    Clip = new RectangleGeometry(new Rect(0, 0, 20, 20))
                };

                Path path2 = new Path
                {
                    Data = Geometry.Parse("M4.5 3.5H12.5L15.5 6.5V16.5H4.5L4.5 3.5Z"),
                    Fill = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#477EDE")),
                };

                Path path3 = new Path
                {
                    Data = Geometry.Parse("M9.95833 12.75C11.6763 12.75 13.1387 11.2833 13.6862 10.6551C13.8279 10.4925 13.8279 10.2575 13.6862 10.0949C13.1387 9.46673 11.6763 8 9.95833 8C8.24035 8 6.778 9.46673 6.23047 10.0949C6.08878 10.2575 6.08878 10.4925 6.23047 10.6551C6.778 11.2833 8.24035 12.75 9.95833 12.75Z"),
                    Fill = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#fff"))
                };

                Path path4 = new Path
                {
                    Data = Geometry.Parse("M9.95833 11.3639C10.5049 11.3639 10.9479 10.9209 10.9479 10.3743C10.9479 9.82782 10.5049 9.38477 9.95833 9.38477C9.41181 9.38477 8.96875 9.82782 8.96875 10.3743C8.96875 10.9209 9.41181 11.3639 9.95833 11.3639Z"),
                    Fill = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#477EDE"))
                };

                viewerCanvas.Children.Add(path1);
                viewerCanvas.Children.Add(path2);
                viewerCanvas.Children.Add(path3);
                viewerCanvas.Children.Add(path4);
            }

            // Annotations
            {
                Path path1 = new Path
                {
                    Data = Geometry.Parse("M11.2071 0.5H0.5V17.5H15.5V4.79289L11.2071 0.5Z"),
                    Fill = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#806675FE")),
                };

                Path path2 = new Path
                {
                    Data = Geometry.Parse("M2.5 2.5H10.5L13.5 5.5V15.5H2.5L2.5 2.5Z"),
                    Fill = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#6675FE")),
                };

                Path path3 = new Path
                {
                    Data = Geometry.Parse("M8.81755 12.6459C8.71612 12.559 8.56646 12.559 8.46503 12.6459L8.32746 12.7639C8.02318 13.0247 7.57419 13.0247 7.26991 12.7639L7.13234 12.6459C7.03091 12.559 6.88125 12.559 6.77982 12.6459L6.59593 12.8036C6.32336 13.0372 5.92977 13.0643 5.62778 12.8701L5.12441 12.5465C4.99859 12.4656 4.96216 12.2981 5.04305 12.1722C5.12393 12.0464 5.2915 12.01 5.41733 12.0909L5.9207 12.4145C6.02136 12.4792 6.15256 12.4702 6.24341 12.3923L6.4273 12.2347C6.73158 11.9739 7.18058 11.9739 7.48486 12.2347L7.62243 12.3526C7.72385 12.4395 7.87352 12.4395 7.97494 12.3526L8.11251 12.2347C8.41679 11.9739 8.86579 11.9739 9.17006 12.2347L9.35396 12.3923C9.44481 12.4702 9.57601 12.4792 9.67667 12.4145L10.18 12.0909C10.3059 12.01 10.4734 12.0464 10.5543 12.1722C10.6352 12.2981 10.5988 12.4656 10.473 12.5465L9.96959 12.8701C9.6676 13.0643 9.27401 13.0372 9.00144 12.8036L8.81755 12.6459Z"),
                    Fill = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#fff"))
                };

                Path path4 = new Path
                {
                    Data = Geometry.Parse("M10.5066 6V7.15097H8.50593V11.0556H7.09957V7.15097H5.08984V6H10.5066Z"),
                    Fill = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#fff"))
                };

                annotationsCanvas.Children.Add(path1);
                annotationsCanvas.Children.Add(path2);
                annotationsCanvas.Children.Add(path3);
                annotationsCanvas.Children.Add(path4);
            }

            // Forms
            {
                Path path1 = new Path
                {
                    Data = Geometry.Parse("M6.12502 4.25H1.90628V6.76817H6.12502V4.25ZM0.500028 3.55233V1.19767C0.500028 0.81236 0.812387 0.5 1.1977 0.5H14.8024C15.1877 0.5 15.5 0.81236 15.5 1.19767V3.55233V14.8023C15.5 15.1876 15.1877 15.5 14.8024 15.5H1.1977C0.812388 15.5 0.500028 15.1876 0.500028 14.8023V8.17442H0.5V6.76817H0.500028V3.55233ZM7.53127 4.25H14.0938V6.76817H7.53127V4.25ZM1.90628 8.17442H6.12502V14.0938H1.90628V8.17442ZM7.53127 14.0938H14.0938V8.17442H7.53127V14.0938ZM13.2437 9.73906C13.3232 9.81854 13.3232 9.94741 13.2437 10.0269L10.7112 12.5594C10.4552 12.8154 10.0403 12.8154 9.78432 12.5594L8.37532 11.1504C8.29584 11.071 8.29584 10.9421 8.37532 10.8626L8.74955 10.4884C8.82903 10.4089 8.9579 10.4089 9.03738 10.4884L10.2478 11.6988L12.5817 9.36484C12.6612 9.28535 12.79 9.28535 12.8695 9.36484L13.2437 9.73906Z"),
                    Stroke = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#fff")),
                };

                Path path2 = new Path
                {
                    Data = Geometry.Parse("M6.12502 4.25H1.90628V6.76817H6.12502V4.25ZM0.500028 3.55233V1.19767C0.500028 0.81236 0.812387 0.5 1.1977 0.5H14.8024C15.1877 0.5 15.5 0.81236 15.5 1.19767V3.55233V14.8023C15.5 15.1876 15.1877 15.5 14.8024 15.5H1.1977C0.812388 15.5 0.500028 15.1876 0.500028 14.8023V8.17442H0.5V6.76817H0.500028V3.55233ZM7.53127 4.25H14.0938V6.76817H7.53127V4.25ZM1.90628 8.17442H6.12502V14.0938H1.90628V8.17442ZM7.53127 14.0938H14.0938V8.17442H7.53127V14.0938ZM13.2437 9.73906C13.3232 9.81854 13.3232 9.94741 13.2437 10.0269L10.7112 12.5594C10.4552 12.8154 10.0403 12.8154 9.78432 12.5594L8.37532 11.1504C8.29584 11.071 8.29584 10.9421 8.37532 10.8626L8.74955 10.4884C8.82903 10.4089 8.9579 10.4089 9.03738 10.4884L10.2478 11.6988L12.5817 9.36484C12.6612 9.28535 12.79 9.28535 12.8695 9.36484L13.2437 9.73906Z"),
                    Fill = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#477EDE")),
                };



                formsCanvas.Children.Add(path1);
                formsCanvas.Children.Add(path2);
            }

            // Signature
            {
                Path path1 = new Path
                {
                    Data = Geometry.Parse("M11.4771 3.16735C11.6151 2.96809 11.8998 2.94242 12.0712 3.11378L15.2582 6.30084C15.4296 6.4722 15.4039 6.75692 15.2047 6.89487L12.0633 9.06966C12.0332 9.09048 12.0114 9.12124 12.0018 9.15653L11.2248 12.0057C11.2059 12.0747 11.143 12.123 11.0717 12.1277C10.7929 12.1458 10.0064 12.2356 8.44611 12.6725C7.06518 13.0592 5.39632 13.8125 4.47439 14.2527C4.61684 14.5428 4.56744 14.9032 4.32618 15.1445C4.0228 15.4479 3.53092 15.4479 3.22754 15.1445C2.92415 14.8411 2.92415 14.3492 3.22754 14.0458C3.46379 13.8096 3.81435 13.7573 4.10119 13.889C4.57233 12.8495 5.42026 10.9231 5.69949 9.92588C6.02875 8.74998 6.19116 7.62277 6.23578 7.28285C6.24404 7.21992 6.28895 7.16832 6.35019 7.15162L9.21546 6.37018C9.25075 6.36056 9.28151 6.33879 9.30233 6.30872L11.4771 3.16735ZM14.7596 14.6595C14.7015 14.6633 14.6428 14.6651 14.5837 14.6651C14.5253 14.6651 14.4673 14.6633 14.4098 14.6597L13.209 16.7396C13.148 16.8452 12.9948 16.8427 12.9374 16.7352L12.4679 15.8567C12.44 15.8045 12.3849 15.7726 12.3258 15.7746L11.3303 15.8073C11.2084 15.8113 11.1297 15.6799 11.1906 15.5743L12.372 13.5281C12.0527 13.0824 11.8647 12.5362 11.8647 11.9461C11.8647 10.4445 13.082 9.22712 14.5837 9.22712C16.0854 9.22712 17.3027 10.4445 17.3027 11.9461C17.3027 12.5355 17.1152 13.0811 16.7966 13.5264L17.9789 15.5743C18.0399 15.6799 17.9611 15.8113 17.8393 15.8073L16.8437 15.7746C16.7846 15.7726 16.7295 15.8045 16.7016 15.8567L16.2322 16.7352C16.1747 16.8427 16.0215 16.8452 15.9606 16.7396L14.7596 14.6595Z"),
                    Fill = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#6675FE")),
                };

                Path path2 = new Path
                {
                    Data = Geometry.Parse("M8.66951 8.63805C8.69551 8.59472 8.75532 8.58735 8.79106 8.62309L9.74899 9.58102C9.78473 9.61676 9.77737 9.67657 9.73403 9.70257L7.33919 11.1395C7.26984 11.1811 7.191 11.1022 7.23261 11.0329L8.66951 8.63805Z"),
                    Fill = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#fff")),
                };

                signatureCanvas.Children.Add(path1);
                signatureCanvas.Children.Add(path2);
            }

            // Document Editor
            {
                Path path1 = new Path
                {
                    Data = Geometry.Parse("M8.6 17.5H15.5V9.6H8.6V17.5ZM15.5 8.4V0.5H8.6V8.4H15.5ZM7.4 17.5V9.6H0.5V17.5H7.4ZM0.5 8.4H7.4V0.5H0.5V8.4Z"),
                    Fill = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#477EDE")),
                };
                documentEditorCanvas.Children.Add(path1);
            }

            // Content Editor
            {
                Path path1 = new Path
                {
                    Data = Geometry.Parse("M4.13281 15.8681V4.13281H15.8681V15.8681H4.13281Z"),
                    Stroke = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#F08E26")),
                    StrokeThickness = 1.5
                };

                Path path2 = new Path
                {
                    Data = Geometry.Parse("M6.42546 6.0293C6.33775 6.0293 6.26664 6.1004 6.26664 6.18812V6.7528C6.26664 6.84051 6.33775 6.91162 6.42546 6.91162H8.83596C8.92368 6.91162 8.99478 6.84051 8.99478 6.7528V6.18812C8.99478 6.1004 8.92368 6.0293 8.83596 6.0293H6.42546ZM10.1456 6.02938C10.0579 6.02938 9.98679 6.10049 9.98679 6.1882V8.51753C9.98679 8.60524 10.0579 8.67635 10.1456 8.67635H13.5482C13.6359 8.67635 13.707 8.60524 13.707 8.51753V6.1882C13.707 6.10049 13.6359 6.02938 13.5482 6.02938H10.1456ZM6.2666 7.95299C6.2666 7.86527 6.33771 7.79416 6.42543 7.79416H8.83592C8.92364 7.79416 8.99475 7.86527 8.99475 7.95299V8.51766C8.99475 8.60538 8.92364 8.67649 8.83592 8.67649H6.42543C6.33771 8.67649 6.2666 8.60538 6.2666 8.51766V7.95299ZM6.42543 9.55876C6.33771 9.55876 6.2666 9.62987 6.2666 9.71759V10.2823C6.2666 10.37 6.33771 10.4411 6.42542 10.4411H13.5482C13.6359 10.4411 13.707 10.37 13.707 10.2823V9.71759C13.707 9.62987 13.6359 9.55876 13.5482 9.55876H6.42543ZM6.2666 11.4822C6.2666 11.3945 6.33771 11.3234 6.42543 11.3234H13.5482C13.6359 11.3234 13.707 11.3945 13.707 11.4822V12.0469C13.707 12.1346 13.6359 12.2057 13.5482 12.2057H6.42542C6.33771 12.2057 6.2666 12.1346 6.2666 12.0469V11.4822ZM6.42543 13.0881C6.33771 13.0881 6.2666 13.1593 6.2666 13.247V13.8116C6.2666 13.8994 6.33771 13.9705 6.42542 13.9705H11.3161C11.4038 13.9705 11.4749 13.8994 11.4749 13.8116V13.247C11.4749 13.1593 11.4038 13.0881 11.3161 13.0881H6.42543Z"),
                    Fill = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#F08E26")),
                };


                for (int i = 0; i < 4; i++)
                {
                    Rectangle rectangle = new Rectangle
                    {
                        Width = 2.64706,
                        Height = 2.64706,
                        RadiusX = 0.441176,
                        RadiusY = 0.441176,
                        Fill = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#F08E26")),
                        Opacity = 0.5
                    };

                    switch (i)
                    {
                        case 0:
                            Canvas.SetLeft(rectangle, 2.5);
                            Canvas.SetTop(rectangle, 2.5);
                            break;
                        case 1:
                            Canvas.SetLeft(rectangle, 14.8525);
                            Canvas.SetTop(rectangle, 2.5);
                            break;
                        case 2:
                            Canvas.SetLeft(rectangle, 2.5);
                            Canvas.SetTop(rectangle, 14.8535);
                            break;
                        case 3:
                            Canvas.SetLeft(rectangle, 14.8525);
                            Canvas.SetTop(rectangle, 14.8535);
                            break;
                    }
                    contentEditorCanvas.Children.Add(rectangle);
                }
                contentEditorCanvas.Children.Add(path1);
                contentEditorCanvas.Children.Add(path2);
            }


        }

        private void UserControl_Unloaded(object sender, RoutedEventArgs e)
        {

        }
    }

}
