﻿using ComPDFKit.PDFDocument;
using Compdfkit_Tools.Common;
using Compdfkit_Tools.Helper;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Forms;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using UserControl = System.Windows.Controls.UserControl;

namespace Compdfkit_Tools.PDFControl
{



    /// <summary>
    /// Interaction logic for FileGridListWithPageRangeControl.xaml
    /// </summary>
    public partial class FileGridListWithPageRangeControl : UserControl, INotifyPropertyChanged
    {
        public static readonly DependencyProperty IsEnsureProperty =
    DependencyProperty.Register(nameof(IsEnsure), typeof(bool), typeof(FileGridListWithPageRangeControl), new PropertyMetadata(false));


        public bool IsEnsure
        {
            get => (bool)GetValue(IsEnsureProperty);
            private set
            {
                SetValue(IsEnsureProperty, value);
            }
        }
        public class FileInfo
        {
            public CPDFDocument Document;
            public string Name { get; set; }
            public string Path { get; set; }
            public string PageRange { get; set; }
            public string Size { get; set; }
        }

        private int _fileNumText;
        public int FileNumText
        {
            get => _fileNumText;
            set
            {
                if (UpdateProper(ref _fileNumText, value))
                    IsEnsure = _fileNumText > 0;
            }
        }


        private ObservableCollection<FileInfo> _fileInfoDataList;
        public ObservableCollection<FileInfo> FileInfoDataList
        {
            get { return _fileInfoDataList; }
            set
            {
                _fileInfoDataList = value;
                _fileInfoDataList.CollectionChanged += (sender, args) =>
                {
                    FileNumText = _fileInfoDataList.Count;
                };
            }
        }

        public FileGridListWithPageRangeControl()
        {
            this.DataContext = this;
            InitializeComponent();
        }

        public event PropertyChangedEventHandler PropertyChanged;
        protected virtual void OnPropertyChanged(string propertyName = null)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }
        protected bool UpdateProper<T>(ref T properValue,
    T newValue,
    [CallerMemberName] string properName = "")
        {
            if (object.Equals(properValue, newValue))
                return false;

            properValue = newValue;
            OnPropertyChanged(properName);
            return true;
        }

        private void AddFilesBtn_Click(object sender, RoutedEventArgs e)
        {
            var openFileDialog = new OpenFileDialog();
            openFileDialog.Multiselect = true;
            openFileDialog.Filter = "PDF Files (*.pdf)|*.pdf";
            if (openFileDialog.ShowDialog() == DialogResult.OK)
            {
                foreach (string filePath in openFileDialog.FileNames)
                {
                    CPDFDocument document = CPDFDocument.InitWithFilePath(filePath);
                    if (document.IsLocked)
                    {
                        PasswordWindow passwordWindow = new PasswordWindow();
                        passwordWindow.InitWithDocument(document);
                        passwordWindow.Owner = Window.GetWindow(this);
                        passwordWindow.PasswordDialog.SetShowText(filePath + " is encrypted.");
                        passwordWindow.ShowDialog();
                        if (document.IsLocked)
                        {
                            document.Release();
                            continue;
                        }

                    }

                    FileInfoDataList.Add(new FileInfo
                    {
                        Document = document,
                        Name = document.FileName,
                        Size = CommonHelper.GetFileSize(filePath),
                        Path = document.FilePath,
                        PageRange = "1-"+document.PageCount.ToString(),
                    });
                }
            }
        }

        private void PasswordWindow_DialogClosed(object sender, PasswordEventArgs e)
        {
            throw new NotImplementedException();
        }

        private void RemoveBtn_Click(object sender, RoutedEventArgs e)
        {

        }

        private void PageRangeBtn_Click(object sender, RoutedEventArgs e)
        {

        }

        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {
            FileInfoDataList = new ObservableCollection<FileInfo>();
            FileDataGrid.ItemsSource = FileInfoDataList;
        }
    }
}
